!+
! Module: imsample_mod
!
! Authors:  Ian Stewart - SSC/LUX
!          
! Description: This task takes as inputs a fits image and a list (fits table) of positions in the image pixel coordinates. The task samples the image at each of the positions and writes the result to a specified column in the fits table.
! 
! Comments: 
!
!
! $Id: module.f90,v 1.6 1998/05/27 13:45:39 gvacanti Exp $
!- 
module imsample_mod

  use dal
  use param  
!  use errorHandling

  use dal_aux

  implicit none 

  private 

  ! Command-line parameters:
  character(255) ::&
    imageSetName,&
    positionSetTabName
  character(20) ::&
    xColumnName,&
    yColumnName,&
    outputColumnName
!***    outputColumnUnits
!***    outputColumnComment

  public imsample

contains 

  !---------------------------------------------------------------------
  subroutine imsample
  !---------------------------------------------------------------------

    implicit none

    real(single), pointer :: image(:,:), xColData(:), yColData(:), sampleData(:)
    integer(int16) :: xSize, ySize, xi, yi
    character(255) :: setName
    character(20) :: tabName
    type(DataSetT) :: set
    type(TableT) :: tab
    type(ColumnT) :: sampleCol
    integer :: row

    !-------------------------------------------------------------------
    ! Start

    call readParameters

    call readArrayData(imageSetName, image) ! ssclib/dal_aux
    xSize = size(image, 1)
    ySize = size(image, 2)

    call splitSetTabName(positionSetTabName, setName, tabName) ! ssclib/dal_aux
    set = dataSet(setName, MODIFY)
    tab = table(set, tabName)
    call readColDataToPtr(tab, xColumnName, xColData) ! ssclib/dal_aux
    call readColDataToPtr(tab, yColumnName, yColData) ! ssclib/dal_aux
    sampleCol = addOrOpenColumn(tab, outputColumnName, REAL32) ! ssclib/dal_aux

    do row = 0, numberOfRows(tab) - 1
      xi = nint(xColData(row))
      yi = nint(yColData(row))
      if (xi < 1 .or. xi > xSize .or. yi < 1 .or. yi > ySize) then
        call setToNull(sampleCol, row)
      end if
    end do

    sampleData => real32Data(sampleCol)

    do row = 0, numberOfRows(tab) - 1
      xi = nint(xColData(row))
      yi = nint(yColData(row))
      if (xi >= 1 .and. xi <= xSize .and. yi >= 1 .and. yi <= ySize) then
        sampleData(row) = image(nint(xColData(row)), nint(yColData(row)))
      end if
    end do

    call release(set)
    deallocate(xColData, yColData, image)

  end subroutine imsample

  !---------------------------------------------------------------------
  subroutine readParameters
  !---------------------------------------------------------------------

    implicit none

    !-------------------------------------------------------------------
    ! Start

    imageSetName = stringParameter('imageset')
    positionSetTabName  = stringParameter('srclisttab')
    xColumnName = stringParameter('xcol')
    yColumnName = stringParameter('ycol')
    outputColumnName = stringParameter('outcol')

  end subroutine readParameters

  !---------------------------------------------------------------------
  subroutine template
  !---------------------------------------------------------------------

    implicit none

    !-------------------------------------------------------------------
    ! Start

  end subroutine template

end module imsample_mod
