//-----------------------------------------------------------------------------
//
//						XMM Science Analysis System (SAS)
//						(c) 1997 European Space Agency
//
//-----------------------------------------------------------------------------
//
//	ttag.cc --- convert event-list Time-Tag to date/time and reverse
//
//	DESCRIPTION:
//		This simple tool takes one argument on the command line
//		with can be either an event list time tag as a single floating point
//		value or a date/time specification in the form yy-mm-ddThh:mm:ss
//		and converts it into the other form:
//
//			ttag <tag>       -> yy-mm-ddThh:mm:ss
//			ttag <datetime>  -> tag
//
//		The result is printed on stdout - return value is 0 upon
//		sucessful exit, != 0 otherwise
//
//	CHANGE HISTORY:
//		UL, 1998-05-26: 1.0.0: - initial version
//		UL, 1998-10-06: 1.1.0: - #include <iomanip> added
//
//	AUTHOR:
//		U. Lammers, Tue May 26 17:37:41 MET DST 1998
//
//	REFERENCES:
//		[1]: Software Specification Document for the XMM Science Analysis
//			 Subsystem, M. Dahlem et. al., 
//
//	$Header: /home/sasbuild/repositories/sasdev/sas/packages/tools/src/ttag/ttag.cc,v 1.5 2003/01/21 13:50:02 ulammers Exp $
//
#include <iostream>
#include <iomanip>
#include <sstream>
#include <string>
#include "errstr.h"
#include "STime.h"
#include "Xmm.h"

int main(int argc, char *argv[])
{
	if (argc != 2)
		errstr<<"Usage: "<<argv[0]<<" <expr>\n"<<Sas::fatal(argv[0]);

	string tstr(argv[1]);
	if (tstr.find("T") != string::npos)
		//	this is an date/time spec
		cout<<setprecision(15)<<STime(tstr) - Xmm::missionReferenceTime<<endl;
	else {
		//	this is a tag
		stringstream str; str<<tstr;
		double secs;
		str>>secs;
		STime t = Xmm::missionReferenceTime + secs;
		cout<<t.toString()<<endl;
	}

	return 0;
} // main()

